@@ -1,5 +1,5 @@
 package WebService::Raygun::Messenger;
-$WebService::Raygun::Messenger::VERSION = '0.029';
+$WebService::Raygun::Messenger::VERSION = '0.030';
 use Mouse;
 
 #use Smart::Comments;
@@ -23,8 +23,9 @@ WebService::Raygun::Messenger - Communicate with the Raygun.io endpoint.
             my $exception = $_;
 
             my $message = {
-                error => $error,      # $@ or framework exception (eg. Moose::Exception)
+                error => $exception,        # $@ or framework exception (eg. Moose::Exception)
                 request => $request_object, # i.e. HTTP::Request, Catalyst::Request, etc.
+
                 #... other params
             };
 
