@@ -186,6 +186,7 @@ sub t0040_validate_request : Test(2) {
 sub t0050_generate_entire_message : Test(1) {
     my $self    = shift;
     my $message = WebService::Raygun::Message->new(
+        user => 'test@mail.com',
         client => {
             name      => 'something',
             version   => 2,
@@ -202,7 +203,7 @@ sub t0050_generate_entire_message : Test(1) {
             total_physical_memory => 3
         },
         request => HTTP::Request->new(
-            POST => 'https://www.null.com',
+            GET => 'https://www.null.com?q=Search&time=today&lang=english',
             [ 'Content-Type' => 'text/html', ]
         ),
     );
@@ -222,11 +223,6 @@ sub t0060_error_with_string_only : Test(1) {
     my $message;
     lives_ok {
         $message = WebService::Raygun::Message->new(
-            client => {
-                name      => 'something',
-                version   => 2,
-                clientUrl => 'www.null.com'
-            },
             occurred_on => '2014-06-27T03:15:10+1300',
             error       => "This is my error!",
             environment => {
@@ -252,11 +248,7 @@ sub t0070_error_with_array_strings : Test(1) {
     my $message;
     lives_ok {
         $message = WebService::Raygun::Message->new(
-            client => {
-                name      => 'something',
-                version   => 2,
-                clientUrl => 'www.null.com'
-            },
+            user => 12345,
             occurred_on => '2014-06-27T03:15:10+1300',
             error       => ["This is my error!", "Another error!"],
             environment => {
